@@ -58,30 +58,30 @@ def upload(
             raise
     if debug:
         sys.stdout.write("D: Directory to upload to: %s\n" % incoming)
-    for afile in files_to_upload:
-        path_to_package, package_name = os.path.split(afile)
+    for file_path in files_to_upload:
+        file_directory, file_name = os.path.split(file_path)
         try:
             if debug:
-                sys.stdout.write("D: Uploading File: %s\n" % afile)
+                sys.stdout.write("D: Uploading File: %s\n" % file_path)
             if progress:
                 try:
-                    size = os.stat(afile).st_size
+                    size = os.stat(file_path).st_size
                 except Exception:
                     size = -1
                     if debug:
                         sys.stdout.write(
                                 "D: Determining size of file '%s' failed\n"
-                                % afile)
-            f = open(afile, 'rb')
+                                % file_path)
+            f = open(file_path, 'rb')
             if progress:
                 f = dputhelper.FileWithProgress(
                         f, ptype=progress,
                         progressf=sys.stdout,
                         size=size)
-            sys.stdout.write("  Uploading %s: " % package_name)
+            sys.stdout.write("  Uploading %s: " % file_name)
             sys.stdout.flush()
             ftp_connection.storbinary(
-                    'STOR ' + package_name,
+                    'STOR ' + file_name,
                     f, 1024)
             f.close()
             sys.stdout.write("done.\n")
@@ -93,7 +93,7 @@ def upload(
                     and e.args and e.args[0][:3] == '553'):
                 sys.stdout.write(
                         "Leaving existing %s on the server and continuing\n"
-                        % (package_name))
+                        % (file_name))
                 sys.stdout.write(
                         "NOTE: This existing file may have been"
                         " previously uploaded partially.\n"
@@ -128,7 +128,7 @@ def upload(
             raise
 
 
-# Copyright © 2015–2019 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2021 Ben Finney <bignose@debian.org>
 # Copyright © 2008–2013 Y Giridhar Appaji Nag <appaji@debian.org>
 # Copyright © 2007 Thomas Viehmann <tv@beamnet.de>
 #
