@@ -1,5 +1,3 @@
-# -*- coding: utf-8; -*-
-#
 # test/test_configfile.py
 # Part of ‘dput’, a Debian package upload toolkit.
 #
@@ -9,14 +7,16 @@
 
 """ Unit tests for config file behaviour. """
 
-from __future__ import (absolute_import, unicode_literals)
-
+import builtins
+import configparser
 import doctest
+import io
 import os
 import os.path
 import sys
 import tempfile
 import textwrap
+import unittest.mock
 
 import testtools
 import testtools.matchers
@@ -27,10 +27,6 @@ from .helper import (
         EXIT_STATUS_FAILURE,
         FakeSystemExit,
         FileDouble,
-        StringIO,
-        builtins,
-        configparser,
-        mock,
         patch_system_interfaces,
         setup_file_double_behaviour,
         )
@@ -50,9 +46,9 @@ def make_config_from_stream(stream):
                 },
             )
 
-    config_file = StringIO(stream)
+    config_file = io.StringIO(stream)
     try:
-        config.readfp(config_file)
+        config.read_file(config_file)
     except configparser.ParsingError:
         config = None
 
@@ -73,12 +69,12 @@ def make_config_file_scenarios():
     global_config_file_path = os.path.join(os.path.sep, "etc", "dput.cf")
     user_config_file_path = os.path.join(os.path.expanduser("~"), ".dput.cf")
 
-    fake_file_empty = StringIO()
-    fake_file_bogus = StringIO("b0gUs")
-    fake_file_minimal = StringIO(textwrap.dedent("""\
+    fake_file_empty = io.StringIO()
+    fake_file_bogus = io.StringIO("b0gUs")
+    fake_file_minimal = io.StringIO(textwrap.dedent("""\
             [DEFAULT]
             """))
-    fake_file_simple = StringIO(textwrap.dedent("""\
+    fake_file_simple = io.StringIO(textwrap.dedent("""\
             [DEFAULT]
             hash = md5
             [foo]
@@ -90,7 +86,7 @@ def make_config_file_scenarios():
             allowed_distributions =
             run_dinstall = false
             """))
-    fake_file_simple_host_three = StringIO(textwrap.dedent("""\
+    fake_file_simple_host_three = io.StringIO(textwrap.dedent("""\
             [DEFAULT]
             hash = md5
             [foo]
@@ -108,48 +104,48 @@ def make_config_file_scenarios():
             fqdn = chmrr.example.com
             incoming = chmrr
             """))
-    fake_file_method_local = StringIO(textwrap.dedent("""\
+    fake_file_method_local = io.StringIO(textwrap.dedent("""\
             [foo]
             method = local
             incoming = quux
             """))
-    fake_file_missing_fqdn = StringIO(textwrap.dedent("""\
+    fake_file_missing_fqdn = io.StringIO(textwrap.dedent("""\
             [foo]
             method = ftp
             incoming = quux
             """))
-    fake_file_missing_incoming = StringIO(textwrap.dedent("""\
+    fake_file_missing_incoming = io.StringIO(textwrap.dedent("""\
             [foo]
             method = ftp
             fqdn = quux.example.com
             """))
-    fake_file_default_not_unsigned = StringIO(textwrap.dedent("""\
+    fake_file_default_not_unsigned = io.StringIO(textwrap.dedent("""\
             [DEFAULT]
             allow_unsigned_uploads = false
             [foo]
             method = ftp
             fqdn = quux.example.com
             """))
-    fake_file_default_distribution_only = StringIO(textwrap.dedent("""\
+    fake_file_default_distribution_only = io.StringIO(textwrap.dedent("""\
             [DEFAULT]
             default_host_main = consecteur
             [ftp-master]
             method = ftp
             fqdn = quux.example.com
             """))
-    fake_file_distribution_none = StringIO(textwrap.dedent("""\
+    fake_file_distribution_none = io.StringIO(textwrap.dedent("""\
             [foo]
             method = ftp
             fqdn = quux.example.com
             distributions =
             """))
-    fake_file_distribution_one = StringIO(textwrap.dedent("""\
+    fake_file_distribution_one = io.StringIO(textwrap.dedent("""\
             [foo]
             method = ftp
             fqdn = quux.example.com
             distributions = spam
             """))
-    fake_file_distribution_three = StringIO(textwrap.dedent("""\
+    fake_file_distribution_three = io.StringIO(textwrap.dedent("""\
             [foo]
             method = ftp
             fqdn = quux.example.com
@@ -431,25 +427,32 @@ def patch_runtime_config_options(testcase):
         testcase.test_host = runtime_config_params.get(
                 'test_section', None)
 
-        testcase.runtime_config_parser.set(
+        maybe_set_option(
+                testcase.runtime_config_parser,
                 'DEFAULT', 'method',
                 getattr(testcase, 'config_default_method', "ftp"))
-        testcase.runtime_config_parser.set(
+        maybe_set_option(
+                testcase.runtime_config_parser,
                 'DEFAULT', 'login',
                 getattr(testcase, 'config_default_login', "username"))
-        testcase.runtime_config_parser.set(
+        maybe_set_option(
+                testcase.runtime_config_parser,
                 'DEFAULT', 'scp_compress',
                 str(getattr(testcase, 'config_default_scp_compress', False)))
-        testcase.runtime_config_parser.set(
+        maybe_set_option(
+                testcase.runtime_config_parser,
                 'DEFAULT', 'ssh_config_options',
                 getattr(testcase, 'config_default_ssh_config_options', ""))
-        testcase.runtime_config_parser.set(
+        maybe_set_option(
+                testcase.runtime_config_parser,
                 'DEFAULT', 'distributions',
                 getattr(testcase, 'config_default_distributions', ""))
-        testcase.runtime_config_parser.set(
+        maybe_set_option(
+                testcase.runtime_config_parser,
                 'DEFAULT', 'incoming',
                 getattr(testcase, 'config_default_incoming', "quux"))
-        testcase.runtime_config_parser.set(
+        maybe_set_option(
+                testcase.runtime_config_parser,
                 'DEFAULT', 'allow_dcut',
                 str(getattr(testcase, 'config_default_allow_dcut', True)))
 
@@ -468,31 +471,40 @@ def patch_runtime_config_options(testcase):
                 default=7)
 
         for section_name in testcase.runtime_config_parser.sections():
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'method',
                     getattr(testcase, 'config_method', "ftp"))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'fqdn',
                     getattr(testcase, 'config_fqdn', "quux.example.com"))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'passive_ftp',
                     str(getattr(testcase, 'config_passive_ftp', False)))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'run_lintian',
                     str(getattr(testcase, 'config_run_lintian', False)))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'run_dinstall',
                     str(getattr(testcase, 'config_run_dinstall', False)))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'pre_upload_command',
                     getattr(testcase, 'config_pre_upload_command', ""))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'post_upload_command',
                     getattr(testcase, 'config_post_upload_command', ""))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'progress_indicator',
                     str(getattr(testcase, 'config_progress_indicator', 0)))
-            testcase.runtime_config_parser.set(
+            maybe_set_option(
+                    testcase.runtime_config_parser,
                     section_name, 'allow_dcut',
                     str(getattr(testcase, 'config_allow_dcut', True)))
             if hasattr(testcase, 'config_incoming'):
@@ -512,7 +524,8 @@ def patch_runtime_config_options(testcase):
                     'host': testcase.test_host,
                     }[section_type]
             for (option_name, option_value) in options.items():
-                testcase.runtime_config_parser.set(
+                maybe_set_option(
+                        testcase.runtime_config_parser,
                         section_name, option_name, option_value)
 
 
@@ -521,16 +534,16 @@ class read_configs_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(read_configs_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
         setup_config_file_fixtures(self)
 
         self.test_configparser = configparser.ConfigParser()
-        self.mock_configparser_class = mock.Mock(
+        self.mock_configparser_class = unittest.mock.Mock(
                 'ConfigParser',
                 return_value=self.test_configparser)
 
-        patcher_class_configparser = mock.patch.object(
+        patcher_class_configparser = unittest.mock.patch.object(
                 configparser, "ConfigParser",
                 new=self.mock_configparser_class)
         patcher_class_configparser.start()
@@ -605,7 +618,7 @@ class read_configs_TestCase(testtools.TestCase):
         self.set_test_args()
         dput.dput.read_configs(**self.test_args)
         expected_calls = [
-                mock.call(
+                unittest.mock.call(
                     self.configs_by_name[config_name]['file_double'].path)
                 for config_name in ['global', 'user']]
         builtins.open.assert_has_calls(expected_calls)
@@ -626,6 +639,19 @@ class read_configs_TestCase(testtools.TestCase):
                 """).format(path=config_file_double.path)
         self.assertIn(expected_output, sys.stdout.getvalue())
 
+    def test_emits_no_skip_message_when_debug_false(self):
+        """ Should not emit a “skipping” message when `debug` is false. """
+        self.set_config_file_scenario('global-config-not-exist')
+        self.set_test_args()
+        config_file_double = self.configs_by_name['global']['file_double']
+        self.test_args['debug'] = False
+        dput.dput.read_configs(**self.test_args)
+        expected_calls = [
+                unittest.mock.call(config_file_double.path)]
+        unwanted_output = "skipping"
+        builtins.open.assert_has_calls(expected_calls)
+        self.assertNotIn(unwanted_output, sys.stderr.getvalue())
+
     def test_skips_file_if_not_exist(self):
         """ Should skip a config file if it doesn't exist. """
         self.set_config_file_scenario('global-config-not-exist')
@@ -634,7 +660,7 @@ class read_configs_TestCase(testtools.TestCase):
         self.test_args['debug'] = True
         dput.dput.read_configs(**self.test_args)
         expected_calls = [
-                mock.call(config_file_double.path)]
+                unittest.mock.call(config_file_double.path)]
         expected_output = textwrap.dedent("""\
                 No such file ...: {path}, skipping
                 """).format(path=config_file_double.path)
@@ -652,7 +678,7 @@ class read_configs_TestCase(testtools.TestCase):
         self.test_args['debug'] = True
         dput.dput.read_configs(**self.test_args)
         expected_calls = [
-                mock.call(config_file_double.path)]
+                unittest.mock.call(config_file_double.path)]
         expected_output = textwrap.dedent("""\
                 Read denied on ...: {path}, skipping
                 """).format(path=config_file_double.path)
@@ -733,18 +759,18 @@ class print_config_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(print_config_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
     def test_invokes_config_write_to_stdout(self):
         """ Should invoke config's `write` method with `sys.stdout`. """
         test_config = make_config_from_stream("")
-        mock_config = mock.Mock(test_config)
+        mock_config = unittest.mock.Mock(test_config)
         dput.dput.print_config(mock_config, debug=False)
         mock_config.write.assert_called_with(sys.stdout)
 
 
-# Copyright © 2015–2016 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2021 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
