@@ -1,5 +1,3 @@
-# -*- coding: utf-8; -*-
-#
 # test/test_dcut.py
 # Part of ‘dput’, a Debian package upload toolkit.
 #
@@ -9,9 +7,8 @@
 
 """ Unit tests for ‘dcut’ module. """
 
-from __future__ import (absolute_import, unicode_literals)
-
 import doctest
+import io
 import itertools
 import os
 import shutil
@@ -19,6 +16,7 @@ import subprocess
 import sys
 import tempfile
 import textwrap
+import unittest.mock
 
 import pkg_resources
 import testscenarios
@@ -27,15 +25,16 @@ import testtools
 import dput.dcut
 from dput.helper import dputhelper
 
+from . import test_dput_main
 from .helper import (
-        ARG_ANY, ARG_MORE,
-        EXIT_STATUS_FAILURE, EXIT_STATUS_SUCCESS,
+        ARG_ANY,
+        ARG_MORE,
+        EXIT_STATUS_FAILURE,
+        EXIT_STATUS_SUCCESS,
         FakeSystemExit,
         FileDouble,
         PasswdEntry,
-        StringIO,
         SubprocessDouble,
-        mock,
         patch_os_environ,
         patch_os_getpid,
         patch_os_getuid,
@@ -60,7 +59,6 @@ from .test_changesfile import (
 from .test_configfile import (
         set_config,
         )
-from . import test_dput_main
 from .test_dputhelper import (
         patch_getopt,
         patch_pkg_resources_get_distribution,
@@ -102,7 +100,7 @@ def patch_getoptions(testcase):
         result = (options, arguments)
         return result
 
-    func_patcher = mock.patch.object(
+    func_patcher = unittest.mock.patch.object(
             dput.dcut, "getoptions", autospec=True,
             side_effect=fake_getoptions)
     func_patcher.start()
@@ -122,7 +120,7 @@ class make_usage_message_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(make_usage_message_TestCase, self).setUp()
+        super().setUp()
 
         patch_sys_argv(self)
 
@@ -148,7 +146,7 @@ class getoptions_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(getoptions_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         patch_os_environ(self)
@@ -176,7 +174,7 @@ class getoptions_TestCase(testtools.TestCase):
         if hasattr(self, 'mailname_fake_file'):
             double = FileDouble(path, self.mailname_fake_file)
         else:
-            double = FileDouble(path, StringIO())
+            double = FileDouble(path, io.StringIO())
         if hasattr(self, 'mailname_file_open_scenario_name'):
             double.set_open_scenario(self.mailname_file_open_scenario_name)
         self.mailname_file_double = double
@@ -216,7 +214,8 @@ class getoptions_TestCase(testtools.TestCase):
 
     def patch_distribution(self):
         """ Patch the Python distribution for this test case. """
-        self.fake_distribution = mock.MagicMock(pkg_resources.Distribution)
+        self.fake_distribution = unittest.mock.MagicMock(
+                pkg_resources.Distribution)
         if hasattr(self, 'dcut_version'):
             self.fake_distribution.version = self.dcut_version
         patch_pkg_resources_get_distribution(self)
@@ -227,7 +226,7 @@ class getoptions_TestCase(testtools.TestCase):
             text = self.dcut_usage_message
         else:
             text = self.getUniqueString()
-        func_patcher = mock.patch.object(
+        func_patcher = unittest.mock.patch.object(
                 dput.dcut, "make_usage_message", autospec=True,
                 return_value=text)
         func_patcher.start()
@@ -292,7 +291,7 @@ class getoptions_UploaderTestCase(
 
     system_scenarios = [
             ('domain-from-mailname-file', {
-                'mailname_fake_file': StringIO("consecteur.example.org"),
+                'mailname_fake_file': io.StringIO("consecteur.example.org"),
                 'pwd_getpwuid_return_value': dummy_pwent._replace(
                         pw_name="grue",
                         pw_gecos="Dolor Sit Amet,spam,beans,eggs"),
@@ -334,7 +333,7 @@ class getoptions_UploaderTestCase(
 
     def setUp(self, *args, **kwargs):
         """ Set up test fixtures. """
-        super(getoptions_UploaderTestCase, self).setUp(*args, **kwargs)
+        super().setUp(*args, **kwargs)
 
         self.set_expected_uploader()
 
@@ -367,6 +366,15 @@ class getoptions_UploaderTestCase(
         expected_output = "\n".join(expected_output_lines)
         self.assertIn(expected_output, sys.stdout.getvalue())
 
+    def test_emits_no_debug_message_for_uploader_discovery(self):
+        """ Should emit no debug message for uploader discovery. """
+        if "--debug" in sys.argv:
+            sys.argv.remove("--debug")
+        dput.dcut.getoptions()
+        expected_output_lines = []
+        expected_output = "\n".join(expected_output_lines)
+        self.assertEqual(expected_output, sys.stdout.getvalue())
+
 
 class getoptions_ParseCommandLineTestCase(
         testscenarios.WithScenarios,
@@ -524,7 +532,7 @@ class getoptions_ParseCommandLineTestCase(
         except FakeSystemExit:
             pass
         dputhelper.getopt.assert_called_with(
-                self.sys_argv[1:], mock.ANY, mock.ANY)
+                self.sys_argv[1:], unittest.mock.ANY, unittest.mock.ANY)
 
     def test_emits_debug_message_for_each_option(self):
         """ Should emit a debug message for each option processed. """
@@ -575,7 +583,7 @@ class getoptions_DetermineHostTestCase(
 
     system_scenarios = [
             ('domain-from-mailname-file', {
-                'mailname_fake_file': StringIO("consecteur.example.org"),
+                'mailname_fake_file': io.StringIO("consecteur.example.org"),
                 }),
             ]
 
@@ -647,7 +655,7 @@ class parse_queuecommands_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(parse_queuecommands_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.set_test_args()
@@ -797,7 +805,7 @@ class create_commands_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(create_commands_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         self.changes_file_scenarios = make_changes_file_scenarios()
@@ -938,7 +946,7 @@ class write_commands_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(write_commands_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         patch_os_getpid(self)
@@ -1051,7 +1059,7 @@ class write_commands_TestCase(
 
     def test_output_file_has_expected_content(self):
         """ Should have expected content in output file. """
-        with mock.patch.object(
+        with unittest.mock.patch.object(
                 self.commands_file_double.fake_file, "close", autospec=True):
             dput.dcut.write_commands(**self.test_args)
         expected_value = self.make_expected_content()
@@ -1105,7 +1113,7 @@ class upload_TestCase(test_dput_main.main_TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(upload_TestCase, self).setUp()
+        super().setUp()
 
         self.set_cat_subprocess_double()
         patch_subprocess_call(self)
@@ -1299,8 +1307,9 @@ class upload_DiscoverLoginTestCase(
         upload_method_func = get_upload_method_func(self)
         self.function_to_test(**self.test_args)
         upload_method_func.assert_called_with(
-                mock.ANY, self.expected_login,
-                mock.ANY, mock.ANY, mock.ANY, mock.ANY)
+                unittest.mock.ANY, self.expected_login,
+                unittest.mock.ANY, unittest.mock.ANY,
+                unittest.mock.ANY, unittest.mock.ANY)
 
 
 class upload_SimulateTestCase(
@@ -1315,7 +1324,14 @@ class upload_SimulateTestCase(
                     'simulate': True,
                     },
                 }),
-            ('simulate three-files', {
+            ('simulate files-one', {
+                'config_default_login': "login-from-config-default",
+                'test_args_extra': {
+                    'simulate': True,
+                    },
+                'files_to_upload': [tempfile.mktemp()],
+                }),
+            ('simulate files-three', {
                 'config_default_login': "login-from-config-default",
                 'test_args_extra': {
                     'simulate': True,
@@ -1347,7 +1363,7 @@ class upload_SimulateTestCase(
         """ Should call ‘cat’ for each file to upload. """
         self.function_to_test(**self.test_args)
         for path in self.files_to_upload:
-            expected_call = mock.call(
+            expected_call = unittest.mock.call(
                     "cat {path}".format(path=path),
                     shell=True)
             self.expectThat(
@@ -1365,7 +1381,8 @@ class upload_UploadMethodTestCase(
                 'config_method': "local",
                 'config_progress_indicator': 23,
                 'expected_args': (
-                    "localhost", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "localhost", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     0),
                 }),
             ('method-ftp', {
@@ -1374,7 +1391,8 @@ class upload_UploadMethodTestCase(
                 'config_passive_ftp': False,
                 'config_progress_indicator': 23,
                 'expected_args': (
-                    "foo.example.com", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     False),
                 'expected_stdout_output': "",
                 }),
@@ -1384,8 +1402,8 @@ class upload_UploadMethodTestCase(
                 'config_passive_ftp': False,
                 'config_progress_indicator': 23,
                 'expected_args': (
-                    "foo.example.com:42",
-                    mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com:42", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     False),
                 'expected_stdout_output': "",
                 }),
@@ -1395,7 +1413,8 @@ class upload_UploadMethodTestCase(
                 'config_passive_ftp': True,
                 'config_progress_indicator': 23,
                 'expected_args': (
-                    "foo.example.com", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     True),
                 'expected_stdout_output': "",
                 }),
@@ -1408,7 +1427,8 @@ class upload_UploadMethodTestCase(
                     'ftp_passive_mode': False,
                     },
                 'expected_args': (
-                    "foo.example.com", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     True),
                 'expected_stdout_output': "D: Using active ftp",
                 }),
@@ -1420,7 +1440,8 @@ class upload_UploadMethodTestCase(
                     'ftp_passive_mode': True,
                     },
                 'expected_args': (
-                    "foo.example.com", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     True),
                 'expected_stdout_output': "D: Using passive ftp",
                 }),
@@ -1433,7 +1454,8 @@ class upload_UploadMethodTestCase(
                     'ftp_passive_mode': True,
                     },
                 'expected_args': (
-                    "foo.example.com", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     True),
                 'expected_stdout_output': "D: Using passive ftp",
                 }),
@@ -1441,7 +1463,8 @@ class upload_UploadMethodTestCase(
                 'config_method': "scp",
                 'config_fqdn': "foo.example.com",
                 'expected_args': (
-                    "foo.example.com", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     False, []),
                 'expected_stdout_output': "",
                 }),
@@ -1455,7 +1478,8 @@ class upload_UploadMethodTestCase(
                         },
                     },
                 'expected_args': (
-                    "foo.example.com", mock.ANY, mock.ANY, mock.ANY, mock.ANY,
+                    "foo.example.com", unittest.mock.ANY, unittest.mock.ANY,
+                    unittest.mock.ANY, unittest.mock.ANY,
                     True, ["spam eggs beans"]),
                 'expected_stdout_output': "D: Setting compression for scp",
                 }),
@@ -1494,12 +1518,14 @@ class upload_UploadMethodTestCase(
             ]
 
     files_scenarios = [
-            ('no-files', {
+            ('files-none', {
                 'files_to_remove': [],
                 }),
-            ('three-files', {
-                'files_to_remove': [
-                        tempfile.mktemp() for __ in range(3)],
+            ('files-one', {
+                'files_to_remove': [tempfile.mktemp()],
+                }),
+            ('files-three', {
+                'files_to_remove': [tempfile.mktemp() for __ in range(3)],
                 }),
             ]
 
@@ -1526,7 +1552,7 @@ class dcut_TestCase(testtools.TestCase):
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(dcut_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         patch_tempfile_mkdtemp(self)
@@ -1558,28 +1584,28 @@ class dcut_TestCase(testtools.TestCase):
 
     def patch_parse_queuecommands(self):
         """ Patch the `parse_queuecommands` function for this test case. """
-        func_patcher = mock.patch.object(
+        func_patcher = unittest.mock.patch.object(
                 dput.dcut, "parse_queuecommands", autospec=True)
         func_patcher.start()
         self.addCleanup(func_patcher.stop)
 
     def patch_create_commands(self):
         """ Patch the `create_commands` function for this test case. """
-        func_patcher = mock.patch.object(
+        func_patcher = unittest.mock.patch.object(
                 dput.dcut, "create_commands", autospec=True)
         func_patcher.start()
         self.addCleanup(func_patcher.stop)
 
     def patch_write_commands(self):
         """ Patch the `write_commands` function for this test case. """
-        func_patcher = mock.patch.object(
+        func_patcher = unittest.mock.patch.object(
                 dput.dcut, "write_commands", autospec=True)
         func_patcher.start()
         self.addCleanup(func_patcher.stop)
 
     def patch_upload_stolen_from_dput_main(self):
         """ Patch `upload_stolen_from_dput_main` for this test case. """
-        func_patcher = mock.patch.object(
+        func_patcher = unittest.mock.patch.object(
                 dput.dcut, "upload_stolen_from_dput_main", autospec=True)
         func_patcher.start()
         self.addCleanup(func_patcher.stop)
@@ -1605,13 +1631,13 @@ class dcut_ConfigFileTestCase(
 
     scenarios = [
             ('default', {
-                'expected_args': (None, mock.ANY),
+                'expected_args': (None, unittest.mock.ANY),
                 }),
             ('config-from-command-line', {
                 'getoptions_opts': {
                     'config': "lorem.conf",
                     },
-                'expected_args': ("lorem.conf", mock.ANY),
+                'expected_args': ("lorem.conf", unittest.mock.ANY),
                 }),
             ]
 
@@ -1730,13 +1756,20 @@ class dcut_NamedHostTestCase(
         self.assertEqual(self.expected_host, options['host'])
 
 
-class dcut_FileToUploadBadNameTestCase(
+class dcut_FileToUploadNameTestCase(
         testscenarios.WithScenarios,
         dcut_TestCase):
     """ Test cases for `dcut` function, file to upload with bad name. """
 
     scenarios = [
-            ('filetoupload', {
+            ('filetoupload suffix-normal', {
+                'getoptions_args': [],
+                'getoptions_opts': {
+                    'filetoupload': tempfile.mktemp() + ".commands",
+                    },
+                'unwanted_output': "Error",
+                }),
+            ('filetoupload suffix-unexpected', {
                 'getoptions_args': [],
                 'getoptions_opts': {
                     'filetoupload': tempfile.mktemp(),
@@ -1749,7 +1782,10 @@ class dcut_FileToUploadBadNameTestCase(
     def test_emits_error_message_for_bad_filename(self):
         """ Should emit error message for bad filename. """
         dput.dcut.dcut(**self.test_args)
-        self.assertIn(self.expected_output, sys.stdout.getvalue())
+        if getattr(self, 'expected_output', None):
+            self.assertIn(self.expected_output, sys.stdout.getvalue())
+        else:
+            self.assertNotIn(self.unwanted_output, sys.stdout.getvalue())
 
 
 class dcut_ParseChangesTestCase(
@@ -1758,11 +1794,180 @@ class dcut_ParseChangesTestCase(
     """ Test cases for `dcut` function, parse upload control file. """
 
     scenarios = [
-            ('changes-file no-filetoupload', {
+            ('changes-file with-filetoupload with-filetocreate', {
                 'getoptions_opts': {
-                    'filetoupload': None,
+                    'filetoupload': tempfile.mktemp(),
+                    'filetocreate': tempfile.mktemp(),
                     'changes': tempfile.mktemp(),
                     },
+                'expect_create_commands': False,
+                'expect_write_commands': False,
+                'expected_tempdir': None,
+                }),
+            ('changes-file no-filetoupload with-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': None,
+                    'filetocreate': tempfile.mktemp(),
+                    'changes': tempfile.mktemp(),
+                    },
+                'expect_create_commands': True,
+                'expect_write_commands': True,
+                'expected_tempdir': None,
+                }),
+            ('changes-file with-filetoupload no-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': tempfile.mktemp(),
+                    'filetocreate': None,
+                    'changes': tempfile.mktemp(),
+                    },
+                'expect_create_commands': False,
+                'expect_write_commands': False,
+                'expected_tempdir': None,
+                }),
+            ('changes-file no-filetoupload no-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': None,
+                    'filetocreate': None,
+                    'changes': tempfile.mktemp(),
+                    },
+                'expect_create_commands': True,
+                'expect_write_commands': True,
+                }),
+            ]
+
+    def test_calls_create_commands_with_expected_args(self):
+        """ Should call `create_commands` as expected. """
+        dput.dcut.dcut(**self.test_args)
+        (expected_options, __) = dput.dcut.getoptions()
+        expected_config = self.runtime_config_parser
+        expected_parse_changes = dput.dput.parse_changes
+        if self.expect_create_commands:
+            dput.dcut.create_commands.assert_called_with(
+                    expected_options, expected_config, expected_parse_changes)
+        else:
+            self.assertFalse(dput.dcut.create_commands.called)
+
+    def test_calls_write_commands_with_expected_args(self):
+        """ Should call `write_commands` as expected. """
+        expected_commands = dput.dcut.create_commands.return_value
+        dput.dcut.dcut(**self.test_args)
+        (expected_options, __) = dput.dcut.getoptions()
+        expected_config = self.runtime_config_parser
+        expected_tempdir = getattr(
+                self, 'expected_tempdir',
+                self.tempfile_mkdtemp_file_double.path)
+        if self.expect_write_commands:
+            dput.dcut.write_commands.assert_called_with(
+                    expected_commands, expected_options, expected_config,
+                    expected_tempdir)
+        else:
+            self.assertFalse(dput.dcut.write_commands.called)
+
+
+class dcut_ParseCommandsFromArgumentsTestCase(
+        testscenarios.WithScenarios,
+        dcut_TestCase):
+    """ Test cases for `dcut` function, parse commands from arguments. """
+
+    scenarios = [
+            ('no-changes-file with-filetoupload with-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': tempfile.mktemp(),
+                    'filetocreate': tempfile.mktemp(),
+                    'changes': None,
+                    },
+                'expect_parse_queuecommands': False,
+                'expect_write_commands': False,
+                'expected_tempdir': None,
+                }),
+            ('no-changes-file no-filetoupload with-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': None,
+                    'filetocreate': tempfile.mktemp(),
+                    'changes': None,
+                    },
+                'expect_parse_queuecommands': True,
+                'expect_write_commands': True,
+                'expected_tempdir': None,
+                }),
+            ('no-changes-file with-filetoupload no-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': tempfile.mktemp(),
+                    'filetocreate': None,
+                    'changes': None,
+                    },
+                'expect_parse_queuecommands': False,
+                'expect_write_commands': False,
+                'expected_tempdir': None,
+                }),
+            ('no-changes-file no-filetoupload no-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': None,
+                    'filetocreate': None,
+                    'changes': None,
+                    },
+                'expect_parse_queuecommands': True,
+                'expect_write_commands': True,
+                }),
+            ]
+
+    def test_calls_parse_queuecommands_with_expected_args(self):
+        """ Should call `parse_queuecommands` with expected args. """
+        dput.dcut.dcut(**self.test_args)
+        (expected_options, expected_arguments) = dput.dcut.getoptions()
+        expected_config = self.runtime_config_parser
+        if self.expect_parse_queuecommands:
+            dput.dcut.parse_queuecommands.assert_called_with(
+                    expected_arguments, expected_options, expected_config)
+        else:
+            self.assertFalse(dput.dcut.parse_queuecommands.called)
+
+    def test_calls_write_commands_with_expected_args(self):
+        """ Should call `write_commands` with expected args. """
+        expected_commands = dput.dcut.parse_queuecommands.return_value
+        dput.dcut.dcut(**self.test_args)
+        (expected_options, __) = dput.dcut.getoptions()
+        expected_config = self.runtime_config_parser
+        expected_tempdir = getattr(
+                self, 'expected_tempdir',
+                self.tempfile_mkdtemp_file_double.path)
+        if self.expect_write_commands:
+            dput.dcut.write_commands.assert_called_with(
+                    expected_commands, expected_options, expected_config,
+                    expected_tempdir)
+        else:
+            self.assertFalse(dput.dcut.write_commands.called)
+
+
+class dcut_WriteQueueCommandsTestCase(
+        testscenarios.WithScenarios,
+        dcut_TestCase):
+    """ Test cases for `dcut` function, cleanup from exception. """
+
+    scenarios = [
+            ('changes-file with-filetoupload with-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': tempfile.mktemp(),
+                    'filetocreate': tempfile.mktemp(),
+                    'changes': tempfile.mktemp(),
+                    },
+                'expected_tempdir': None,
+                }),
+            ('changes-file no-filetoupload with-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': None,
+                    'filetocreate': tempfile.mktemp(),
+                    'changes': tempfile.mktemp(),
+                    },
+                'expected_tempdir': None,
+                }),
+            ('changes-file with-filetoupload no-filetocreate', {
+                'getoptions_opts': {
+                    'filetoupload': tempfile.mktemp(),
+                    'filetocreate': None,
+                    'changes': tempfile.mktemp(),
+                    },
+                'expected_tempdir': None,
                 }),
             ('changes-file no-filetoupload no-filetocreate', {
                 'getoptions_opts': {
@@ -1773,62 +1978,6 @@ class dcut_ParseChangesTestCase(
                 }),
             ]
 
-    def test_calls_create_commands_with_expected_args(self):
-        """ Should call `create_commands` with expected args. """
-        dput.dcut.dcut(**self.test_args)
-        (expected_options, __) = dput.dcut.getoptions()
-        expected_config = self.runtime_config_parser
-        expected_parse_changes = dput.dput.parse_changes
-        dput.dcut.create_commands.assert_called_with(
-                expected_options, expected_config, expected_parse_changes)
-
-    def test_calls_write_commands_with_expected_args(self):
-        """ Should call `write_commands` with expected args. """
-        expected_commands = object()
-        dput.dcut.create_commands.return_value = expected_commands
-        dput.dcut.dcut(**self.test_args)
-        (expected_options, __) = dput.dcut.getoptions()
-        expected_config = self.runtime_config_parser
-        expected_tempdir = self.tempfile_mkdtemp_file_double.path
-        dput.dcut.write_commands.assert_called_with(
-                expected_commands, expected_options, expected_config,
-                expected_tempdir)
-
-
-class dcut_ParseQueueCommandsTestCase(
-        testscenarios.WithScenarios,
-        dcut_TestCase):
-    """ Test cases for `dcut` function, parse commands from arguments. """
-
-    scenarios = [
-            ('no-changes-file no-filetoupload', {
-                'getoptions_opts': {
-                    'filetoupload': None,
-                    'changes': None,
-                    },
-                }),
-            ]
-
-    def test_calls_parse_queuecommands_with_expected_args(self):
-        """ Should call `parse_queuecommands` with expected args. """
-        dput.dcut.dcut(**self.test_args)
-        (expected_options, expected_arguments) = dput.dcut.getoptions()
-        expected_config = self.runtime_config_parser
-        dput.dcut.parse_queuecommands.assert_called_with(
-                expected_arguments, expected_options, expected_config)
-
-    def test_calls_write_commands_with_expected_args(self):
-        """ Should call `write_commands` with expected args. """
-        expected_commands = object()
-        dput.dcut.parse_queuecommands.return_value = expected_commands
-        dput.dcut.dcut(**self.test_args)
-        (expected_options, __) = dput.dcut.getoptions()
-        expected_config = self.runtime_config_parser
-        expected_tempdir = self.tempfile_mkdtemp_file_double.path
-        dput.dcut.write_commands.assert_called_with(
-                expected_commands, expected_options, expected_config,
-                expected_tempdir)
-
 
 class dcut_CleanupTestCase(
         testscenarios.WithScenarios,
@@ -1851,16 +2000,17 @@ class dcut_CleanupTestCase(
     scenarios = testscenarios.multiply_scenarios(
             commands_scenarios, files_scenarios)
 
-    def setUp(self):
-        """ Set up test fixtures. """
-        super(dcut_CleanupTestCase, self).setUp()
-
-        upload_method_func = get_upload_method_func(self)
-        self.upload_error = RuntimeError("Bad stuff happened")
-        upload_method_func.side_effect = self.upload_error
+    def test_removes_temporary_directory(self):
+        """ Should remove directory `tempdir` at end. """
+        dput.dcut.dcut(**self.test_args)
+        shutil.rmtree.assert_called_with(
+                self.tempfile_mkdtemp_file_double.path)
 
     def test_removes_temporary_directory_when_upload_raises_exception(self):
         """ Should remove directory `tempdir` when exception raised. """
+        upload_method_func = get_upload_method_func(self)
+        upload_error = RuntimeError("Bad stuff happened")
+        upload_method_func.side_effect = upload_error
         try:
             dput.dcut.dcut(**self.test_args)
         except self.upload_error.__class__:
@@ -1869,7 +2019,7 @@ class dcut_CleanupTestCase(
                 self.tempfile_mkdtemp_file_double.path)
 
 
-# Copyright © 2015–2016 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2021 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
