@@ -1,5 +1,3 @@
-# -*- coding: utf-8; -*-
-#
 # test/test_dputhelper.py
 # Part of ‘dput’, a Debian package upload toolkit.
 #
@@ -9,8 +7,6 @@
 
 """ Unit tests for ‘dput.helper.dputhelper’ module. """
 
-from __future__ import (absolute_import, unicode_literals)
-
 import collections
 import doctest
 import io
@@ -20,6 +16,7 @@ import os
 import subprocess
 import sys
 import textwrap
+import unittest.mock
 
 import pkg_resources
 import testscenarios
@@ -30,10 +27,9 @@ from dput.helper import dputhelper
 
 from .helper import (
         EXIT_STATUS_COMMAND_NOT_FOUND,
-        EXIT_STATUS_FAILURE, EXIT_STATUS_SUCCESS,
-        StringIO,
+        EXIT_STATUS_FAILURE,
+        EXIT_STATUS_SUCCESS,
         SubprocessDouble,
-        mock,
         patch_subprocess_check_call,
         patch_sys_argv,
         patch_system_interfaces,
@@ -79,7 +75,7 @@ class check_call_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(check_call_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
         patch_subprocess_check_call(self)
@@ -116,127 +112,6 @@ class check_call_TestCase(
                 testtools.matchers.DocTestMatches(
                     self.expected_output, flags=doctest.ELLIPSIS))
 
-
-class TimestampFile_TestCase(testtools.TestCase):
-    """ Base for test cases for the `TimestampFile` class. """
-
-    scenarios = NotImplemented
-
-    def setUp(self):
-        """ Set up test fixtures. """
-        super(TimestampFile_TestCase, self).setUp()
-
-        patch_time_time(self, itertools.count(1))
-
-        self.test_file = StringIO()
-        self.instance = dputhelper.TimestampFile(self.test_file)
-
-
-class TimestampFile_InstanceTestCase(
-        testscenarios.WithScenarios,
-        TimestampFile_TestCase):
-    """ Test cases for `TimestampFile` instance creation. """
-
-    scenarios = [
-            ('default', {}),
-            ]
-
-    def test_has_specified_file(self):
-        """ Should have specified file object as `f` attribute. """
-        self.assertIs(self.test_file, self.instance.f)
-
-    def test_has_attributes_from_component_file(self):
-        """ Should have attributes directly from component file. """
-        attr_names = [
-                'b0gUs',
-                'mode', 'name', 'encoding',
-                'readable', 'seekable', 'writable',
-                'read', 'seek', 'tell',
-                ]
-        for attr_name in attr_names:
-            expected_attr_value = getattr(self.test_file, attr_name, None)
-            self.expectThat(
-                    getattr(self.instance, attr_name, None),
-                    testtools.matchers.Equals(expected_attr_value))
-
-
-class TimestampFile_write_TestCase(
-        testscenarios.WithScenarios,
-        TimestampFile_TestCase):
-    """ Test cases for `TimestampFile.write` method. """
-
-    scenarios = [
-            ('empty', {
-                'test_output': "",
-                'expected_lines': [],
-                }),
-            ('lines-one', {
-                'test_output': textwrap.dedent("""\
-                    Lorem ipsum, dolor sit amet.
-                    """),
-                'expected_lines': [
-                    "1: Lorem ipsum, dolor sit amet.",
-                    "",
-                    ],
-                }),
-            ('lines-three', {
-                'test_output': textwrap.dedent("""\
-                    Lorem ipsum, dolor sit amet,
-                    consectetur adipiscing elit.
-                    Integer non pulvinar risus, sed malesuada diam.
-                    """),
-                'expected_lines': [
-                    "1: Lorem ipsum, dolor sit amet,",
-                    "2: consectetur adipiscing elit.",
-                    "3: Integer non pulvinar risus, sed malesuada diam.",
-                    "",
-                    ],
-                }),
-            ('lines-two-with-trail', {
-                'test_output': textwrap.dedent("""\
-                    Lorem ipsum, dolor sit amet,
-                    consectetur adipiscing elit.
-                    Integer non pulvinar risus"""),
-                'expected_lines': [
-                    "1: Lorem ipsum, dolor sit amet,",
-                    "2: consectetur adipiscing elit.",
-                    "3: Integer non pulvinar risus",
-                    ],
-                }),
-            ]
-
-    def test_has_expected_content_for_output(self):
-        """ Should have expected content for specified `write` output. """
-        self.instance.write(self.test_output)
-        expected_lines = self.expected_lines
-        if self.expected_lines:
-            if self.expected_lines[-1]:
-                # Expecting an unterminated final line.
-                expected_lines = self.expected_lines[:-1]
-                expected_lines.append("")
-            else:
-                # Expecting no output following newline.
-                expected_lines = self.expected_lines
-        expected_content = "\n".join(expected_lines)
-        self.assertEqual(expected_content, self.instance.f.getvalue())
-
-
-class TimestampFile_close_TestCase(
-        testscenarios.WithScenarios,
-        TimestampFile_TestCase):
-    """ Test cases for `TimestampFile.write` method. """
-
-    scenarios = TimestampFile_write_TestCase.scenarios
-
-    @testtools.skip("TimestampFile.close method is broken")
-    def test_has_expected_final_line(self):
-        """ Should have expected final line. """
-        self.instance.write(self.test_output)
-        self.instance.f.seek(0)
-        self.instance.close()
-        expected_content = self.expected_lines[-1]
-        self.assertEqual(expected_content, self.instance.f.getvalue())
-
 
 class FileWithProgress_TestCase(
         testscenarios.WithScenarios,
@@ -252,10 +127,10 @@ class FileWithProgress_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(FileWithProgress_TestCase, self).setUp()
+        super().setUp()
         patch_system_interfaces(self)
 
-        self.test_file = StringIO(
+        self.test_file = io.StringIO(
                 getattr(self, 'content', ""))
 
         self.set_test_args()
@@ -287,7 +162,7 @@ class FileWithProgress_ArgsTestCase(FileWithProgress_TestCase):
             ('simple', {}),
             ('all args', {
                 'test_ptype': 1,
-                'test_progressf': StringIO(),
+                'test_progressf': io.StringIO(),
                 'test_size': 10,
                 'test_step': 2,
                 }),
@@ -352,32 +227,44 @@ class FileWithProgress_OutputTestCase(FileWithProgress_TestCase):
             ]
 
     ptype_scenarios = [
-            ('default', {}),
+            ('ptype default', {}),
             ('ptype 0', {'test_ptype': 0}),
             ('ptype 1', {'test_ptype': 1}),
             ('ptype 2', {'test_ptype': 2}),
             ]
 
+    size_scenarios = [
+            ('size default', {}),
+            ('size 0', {
+                'test_size': 0,
+                }),
+            ('size specified', {
+                'specify_file_size': True,
+                }),
+            ]
+
     step_scenarios = [
-            ('default', {}),
+            ('step default', {}),
             ('step 5', {'test_step': 5}),
             ('step 500', {'test_step': 500}),
             ('step 50 000', {'test_step': 50000}),
             ]
 
     scenarios = testscenarios.multiply_scenarios(
-            content_scenarios, ptype_scenarios, step_scenarios)
+            content_scenarios, ptype_scenarios,
+            size_scenarios, step_scenarios)
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(FileWithProgress_OutputTestCase, self).setUp()
+        super().setUp()
 
-        self.test_file = StringIO(self.content)
-        self.test_size = len(self.content)
-        self.test_progressf = StringIO()
+        self.test_file = io.StringIO(self.content)
+        self.test_progressf = io.StringIO()
         self.set_test_args()
         self.make_instance()
 
+        if getattr(self, 'specify_file_size', False):
+            self.test_size = len(self.content)
         self.set_expected_output()
 
     def set_expected_output(self):
@@ -389,12 +276,17 @@ class FileWithProgress_OutputTestCase(FileWithProgress_TestCase):
             step = getattr(self, 'test_step', 1024)
             total_bytes = len(self.content)
             total_hunks = int(total_bytes / step)
-            total_hunks_text = "{size}k".format(size=total_hunks)
+            total_hunks_text = "{size:d}k".format(size=total_hunks)
+            file_size = getattr(self, 'test_size', self.default_args['size'])
             total_steps = int(
                     (total_bytes + step - 1) / step)
-            total_steps_text = "{size}k".format(size=total_steps)
+            if not file_size:
+                total_steps = 0
+            total_steps_text = "{size:d}k".format(size=total_steps)
             progress_text = "{hunks}/{steps}".format(
                     hunks=total_hunks_text, steps=total_steps_text)
+            if file_size < 0 or getattr(self, 'specify_file_size', False):
+                progress_text = total_hunks_text
             self.expected_output = progress_text
         else:
             # `ptype == 0` specifies no progress output.
@@ -428,7 +320,7 @@ class FileWithProgress_OutputTestCase(FileWithProgress_TestCase):
 def patch_filewithprogress(testcase):
     """ Patch the `FileWithProgress` class for the test case. """
     if not hasattr(testcase, 'fake_filewithprogress'):
-        testcase.fake_filewithprogress = mock.MagicMock(
+        testcase.fake_filewithprogress = unittest.mock.MagicMock(
                 spec=dputhelper.FileWithProgress, name="FileWithProgress")
 
     def fake_filewithprogress_factory(
@@ -441,7 +333,7 @@ def patch_filewithprogress(testcase):
         result.step = step
         return result
 
-    func_patcher = mock.patch.object(
+    func_patcher = unittest.mock.patch.object(
             dputhelper, "FileWithProgress", autospec=True,
             side_effect=fake_filewithprogress_factory)
     func_patcher.start()
@@ -484,27 +376,9 @@ class make_text_stream_TestCase(
                 }),
             ]
 
-    if sys.version_info >= (3, 0):
-        # This version of Python does not have brute `file` type, so
-        # we don't need to test for streams of that type.
-        pass
-    else:
-        # Streams are brute `file` objects in Python < 3, so we need
-        # to test that type also.
-        scenarios.append(
-                ('temp-file', {
-                    'fake_file_params': {
-                        'type': os.tmpfile,
-                        'content': u"Lorem ipsum".encode("utf-8"),
-                        },
-                    'expected_encoding': fake_preferred_encoding,
-                    'expected_content': u"Lorem ipsum",
-                    })
-                )
-
     def setUp(self):
         """ Set up test fixtures. """
-        super(make_text_stream_TestCase, self).setUp()
+        super().setUp()
 
         self.patch_locale_getpreferredencoding()
 
@@ -520,7 +394,7 @@ class make_text_stream_TestCase(
 
     def patch_locale_getpreferredencoding(self):
         """ Patch the `locale.getpreferredencoding` function. """
-        func_patcher = mock.patch.object(
+        func_patcher = unittest.mock.patch.object(
                 locale, "getpreferredencoding", autospec=True,
                 return_value=self.fake_preferred_encoding)
         func_patcher.start()
@@ -795,7 +669,7 @@ def patch_getopt(testcase):
         result = (testcase.getopt_opts, testcase.getopt_args)
         return result
 
-    func_patcher = mock.patch.object(
+    func_patcher = unittest.mock.patch.object(
             dputhelper, "getopt", autospec=True,
             side_effect=fake_getopt)
     func_patcher.start()
@@ -842,7 +716,7 @@ class get_progname_TestCase(
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(get_progname_TestCase, self).setUp()
+        super().setUp()
 
         self.test_argv = [self.argv_zero] + self.argv_remain
 
@@ -862,8 +736,9 @@ class get_progname_TestCase(
 def patch_pkg_resources_get_distribution(testcase):
     """ Patch `pkg_resources.get_distribution` for the test case. """
     if not hasattr(testcase, 'fake_distribution'):
-        testcase.fake_distribution = mock.MagicMock(pkg_resources.Distribution)
-    func_patcher = mock.patch.object(
+        testcase.fake_distribution = unittest.mock.MagicMock(
+                pkg_resources.Distribution)
+    func_patcher = unittest.mock.patch.object(
             pkg_resources, "get_distribution", autospec=True,
             return_value=testcase.fake_distribution)
     func_patcher.start()
@@ -877,14 +752,14 @@ class get_distribution_version_TestCase(
 
     scenarios = [
             ('simple', {
-                'fake_distribution': mock.MagicMock(
+                'fake_distribution': unittest.mock.MagicMock(
                     project_name="lorem", version="42.23"),
                 }),
             ]
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(get_distribution_version_TestCase, self).setUp()
+        super().setUp()
 
         patch_pkg_resources_get_distribution(self)
 
@@ -895,7 +770,7 @@ class get_distribution_version_TestCase(
         self.assertEqual(expected_version, result)
 
 
-# Copyright © 2015–2016 Ben Finney <bignose@debian.org>
+# Copyright © 2015–2021 Ben Finney <bignose@debian.org>
 #
 # This is free software: you may copy, modify, and/or distribute this work
 # under the terms of the GNU General Public License as published by the
